#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QQuickView>
#include <QGeoCoordinate>

#include "markermodel.h"

QT_BEGIN_NAMESPACE
namespace Ui
{
    class MainWindow;
}
QT_END_NAMESPACE

class QMLReceiver : public QObject
{
private:
    Q_OBJECT

public:
    Q_INVOKABLE void centerChanged(QGeoCoordinate coordinate)
    {
        emit centerChangedSignal(coordinate.latitude(), coordinate.longitude());
    }

    Q_INVOKABLE void markerClicked(const QString& identifier, const QString& name, QGeoCoordinate coordinate)
    {
        emit markerClickedSignal(identifier, name, coordinate.latitude(), coordinate.longitude());
    }

signals:
    void centerChangedSignal(float lat, float lon);
    void markerClickedSignal(const QString& identifier, const QString& name, float lat, float lon);
};

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    MainWindow();

    ~MainWindow();

protected:
    virtual bool eventFilter(QObject* obj, QEvent* event) override;

private:
    enum class TextType
    {
        MouseCoord,
        CenterCoord,
        MarkerInfo
    };
    void setInformationText(TextType type, const QString& text);
    std::tuple<float, float> getMouseCoordinates();

private slots:
    void onCenterChanged(float lat, float lon);
    void onMarkerClicked(const QString& identifier, const QString& name, float lat, float lon);

private:
    Ui::MainWindow* _ui;
    QQuickView*     _qml_view;
    QMLReceiver*    _qml_receiver;
    MarkerModel*    _model;
};
#endif // MAINWINDOW_H
