import QtQuick 2.11
import QtLocation 5.11
import QtPositioning 5.11

Rectangle {
    id: main
    width: parent.width
    height: parent.height
    visible: true

    Plugin {
        id: mapPlugin
        name: "esri"
    }

    Map {
        id: mapView
        objectName: "mapView"
        anchors.fill: parent
        plugin: mapPlugin
        center: QtPositioning.coordinate(59.9386, 30.3141)
        zoomLevel: 15

        MouseArea {
            id: mapViewMouseArea
            anchors.fill: parent
            propagateComposedEvents: true
            hoverEnabled: true
        }

        function getMousePosition() {
            return mapView.toCoordinate(Qt.point(mapViewMouseArea.mouseX, mapViewMouseArea.mouseY));
        }

        onCenterChanged: {
            qmlReceiver.centerChanged(center);
        }

        MapItemView {
            model: markerModel
            delegate: mapComponent
        }
    }

    Component {
        id: mapComponent

        MapQuickItem
        {
            id: marker
            anchorPoint.x: image.width/2
            anchorPoint.y: image.height
            coordinate: positionValue

            property string identifier: identifierValue
            property string name: nameValue
            property string icon: iconValue

            sourceItem: Image {
                id: image
                source: icon;
            }

            MouseArea {
                id: mouseArea
                anchors.fill: parent
                hoverEnabled: true
                drag.target: parent

                onClicked: {
                    qmlReceiver.markerClicked(identifier, name, coordinate);
                }
            }
        }
    }
}
