#ifndef MARKERMODEL_H
#define MARKERMODEL_H

#include <QAbstractListModel>
#include <QGeoCoordinate>

struct Marker
{
    QString         _identifier;
    QString         _name;
    QGeoCoordinate  _position;
    QString         _icon;
};

class MarkerModel final : public QAbstractListModel
{
private:
    Q_OBJECT

public:
    enum MarkerRoles
    {
        positionRole = Qt::UserRole + 1,
        identifierRole = Qt::UserRole + 2,
        nameRole = Qt::UserRole + 3,
        iconRole = Qt::UserRole + 4,
    };

    MarkerModel() = default;

    ~MarkerModel() = default;

    void addMarker(const QString& identifier, const QString& name, float lat, float lon, const QString& icon);

    std::tuple<float, float> getMarkerLatLon(const QString& identifier) const;

    void setMarkerLatLon(const QString& identifier, float lat, float lon);

    void setMarkerName(const QString& identifier, const QString& name, bool redraw);

    void setMarkerIcon(const QString& identifier, const QString& icon, bool redraw);

    void delMarker(const QString& identifier);

    void clear();

    void redrawCurrent(const QString& identifier);

    void redrawAll();

    virtual int rowCount(const QModelIndex& parent = QModelIndex()) const override;

    virtual QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;

    virtual QHash<int, QByteArray> roleNames() const override;

private:
    int indexOf(const QString& identifier) const;

private:
    QList<Marker> _markers;
};


#endif // MARKERMODEL_H
